﻿import es
import playerlib
import gamethread
import wcs
import cfglib
import cmdlib
import os
import random
import time
import sys
import langlib
from configobj import ConfigObj
from path import path as Path
from popuplib import easymenu, create, send
import saytextlib


#import actions
#reload(actions)
#from actions import *

addonInfo = es.AddonInfo()
addonInfo.name = 'Level bank'
addonInfo.author = 'Yeti'
addonInfo.basename = 'levelbank'

class Info(object):
	def __init__(self):
		self.path = es.getAddonPath('levelbank')
		self.admins = os.path.join(self.path ,'ini', 'admins.ini')
	
	@property	
	def getAdmins(self):
		return ConfigObj(self.admins)
info = Info()


if os.path.isfile(os.path.join(info.path, 'ini', 'strings.ini')):
	strings = langlib.Strings(os.path.join(info.path, 'ini', 'strings.ini'))
else:
	strings = lambda x, tokens={}, lang='en': es.dbmsg('LEVELBANK EROR')
	

config = cfglib.AddonCFG(os.path.join(info.path, 'config', 'levelbank.cfg'))
dbType				= config.cvar('levelbank_dbType',				2, 'Type of database 1 - MySQL 2 - SQLite')
defaultlevel		= config.cvar('levelbank_defaultlevels',		50, 'Default levels add to user')
mysql_host			= config.cvar('levelbank_mysqlhost',			'', 'Host name. MySQL only')
mysql_user			= config.cvar('levelbank_mysquser',				'', 'User name. MySQL only')
mysql_pass			= config.cvar('levelbank_mysqlpass',			'', 'Password for user. MySQL only')
mysql_dbname		= config.cvar('levelbank_mysqldbname',			'', 'Data base name. MySQL only')
levelprice			= config.cvar('levelbank_levelprice',			16000, 'Price of 1 level in level bank')
levelcost			= config.cvar('levelbank_levelcost',			5000, 'Cost of 1 level in levelbank')
buylevels			= config.cvar('levelbank_buylevels',			0, '1-ON/0 -OFF buy levels')
selllevels			= config.cvar('levelbank_selllevels',			1, '1-ON/0 -OFF sell levels')
config.write()

data = {'dbType':dbType,
		'defaultlevel':defaultlevel,
		'mysql_host':mysql_host,
		'mysql_user':mysql_user,
		'mysql_pass':mysql_pass,
		'mysql_dbname':mysql_dbname,
		'levelprice':levelprice,
		'levelcost':levelcost
}

flag = False
if data['dbType'] == 1:
	import MySQLdb
	flag=True
elif data['dbType'] == 2:
	from sqlite3 import dbapi2 as sqlite
	flag = True
if not flag:
	from sqlite3 import dbapi2 as sqlite
	dbType = 2

class MySQLManager(object):
	def __init__(self):
		if not data['dbType'] == 1:
			return
		self.connection   = MySQLdb.connect(host=str(data['mysql_host']), user=str(data['mysql_user']), passwd=str(data['mysql_pass']), db=str(data['mysql_dbname']))
		self.cursor       = self.connection.cursor()
		self.execute('set session character_set_server=utf8')
		self.execute('set session character_set_database=utf8')
		self.execute('set session character_set_connection=utf8')
		self.execute('set session character_set_results=utf8')
		self.execute('set session character_set_client=utf8')
		try:
			self.execute("""\
				CREATE TABLE Levelbank (
					UserID        INTEGER PRIMARY KEY AUTO_INCREMENT NOT NULL,
					steamid       VARCHAR(30) NOT NULL,
					name          VARCHAR(30) NOT NULL,
					levels	    INTEGER DEFAULT %s,
					ban			INTEGER DEFAULT 0,
					banTimeOut		INTEGER DEFAULT 0,
					banHours	INTEGER DEFAULT 0
				)"""%(str(data['defaultlevel'])))
				
		except:
			pass
			
		try:
			self.execute("CREATE INDEX playersIndex ON Levelbank(steamid)")
		except:
			pass
			
	def __len__(self):
		self.execute("SELECT COUNT(*) FROM Levelbank")
		return int(self.cursor.fetchone()[0])
		
	def __contains__(self, user):
		if isinstance(user, int):
			self.execute("SELECT steamid FROM Levelbank WHERE UserID = %s", (user))
		else:
			self.execute("SELECT steamid FROM Levelbank WHERE steamid = %s", (user))
		return bool(self.cursor.fetchone())

	def __del__(self):
		self.save()
		self.close()

	def execute(self, statement, args=None):
		if args is None:
			self.cursor.execute(statement)
		else:
			self.cursor.execute(statement, args)

	def fetchone(self):
		result = self.cursor.fetchone()
		if hasattr(result, '__iter__'):
			if len(result) == 1:
				return result[0]
		return result
	
	def fetchall(self):
		trueValues = []
		for value in self.cursor.fetchall():
			if isinstance(value, tuple):
				if len(value) > 1:
					trueValues.append(value)
				else:
					trueValues.append(value[0])
			else:
				trueValues.append(value)
		return trueValues

	def save(self):
		self.connection.commit()

	def close(self):
		self.cursor.close()
		self.connection.commit()
	
	def getLevelsFromUserid(self, userid):
		self.execute("SELECT levels FROM Levelbank WHERE UserID = %s", (userid))
		value = self.cursor.fetchone()
		if value == 0:
			self.addLevelToUser(userid, defaultlevel)
			return defaultlevel
		return value[0]
		
	def addLevelToUser(self, userid, amount):
		self.execute("UPDATE Levelbank SET levels = %s WHERE UserID = %s", (amount, userid))
		self.execute("SELECT levels FROM Levelbank WHERE UserID = %s",(userid))
		value = self.cursor.fetchone()
		if value[0] == 0:
			self.addLevelToUser(userid, defaultlevel)
			return defaultlevel
		return value[0]
		
	def addPlayer(self, userid, name, steamid):
		self.execute("INSERT IGNORE INTO Levelbank (UserID, steamid, name, levels) VALUES (%s,%s,%s,%s)",(str(userid),str(self.removeWarnings(name)),str(steamid), str(defaultlevel)))
		self.execute("SELECT UserID FROM Levelbank WHERE steamid = %s",(steamid))
		return self.cursor.lastrowid
		
	def getUserIdFromSteamId(self, steamid):
		self.execute("SELECT UserID FROM Levelbank WHERE steamid = %s",(steamid))
		v = self.cursor.fetchone()
		if v is None:
			return None
		return v[0]
	
	def takeLevels(self, userid, amount):
		self.execute("UPDATE Levelbank SET levels = %s WHERE UserID = %s", (amount, userid))
		self.execute("SELECT levels FROM Levelbank WHERE UserID = %s",(userid))
		return self.cursor.fetchone()[0]
	
	def getBanUser(self, userid):
		self.execute("SELECT ban, banTimeOut, banHours FROM Levelbank WHERE UserID = %s",(userid))
		v = database.fetchone()
		if v[0]:
			baninfo = {'ban':v[0],'banTimeOut':v[1],'banHours':v[2]}
			return baninfo
		return {'ban':0,'banTimeOut':0,'banHours':0}
		
	def banUser(self, userid, time, timeout):
		self.execute("UPDATE Levelbank SET ban = 1, banTimeOut = %s, banHours = %s WHERE UserID = %s",(timeout,time,userid))
		return {'ban':1,'banTimeOut':timeout,'banHours':time}
		
	def unbanUser(self, userid):
		self.execute("UPDATE Levelbank SET ban = 0, banTimeOut = 0, banHours = 0 WHERE UserID = %s",(userid))
		return {'ban':0,'banTimeOut':0,'banHours':0}	
		
		
	def removeWarnings(self, value):
		return str(value).replace("'", "").replace('"', '')
		
		
class SQLiteManager(object):
	def __init__(self, pathFile):
		if not data['dbType'] == 2:
			return
		if isinstance(pathFile, Path):
			self.pathFile = pathFile
		else:
			self.pathFile = Path(pathFile)

		self.connection   = sqlite.connect(self.pathFile.joinpath('levelbank.sqlite'))
		self.cursor       = self.connection.cursor()

		self.connection.text_factory = str
		self.execute("PRAGMA auto_vacuum=FULL")

		self.execute("""\
			CREATE TABLE IF NOT EXISTS Levelbank (
				UserID        INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
				steamid       VARCHAR(30) NOT NULL,
				name          VARCHAR(30) NOT NULL,
				levels	    INTEGER DEFAULT %s,
				ban			INTEGER DEFAULT 0,
				banTimeOut		INTEGER DEFAULT 0,
				banHours	INTEGER DEFAULT 0
			)"""%(str(data['defaultlevel'])))

		self.execute("CREATE INDEX IF NOT EXISTS playersIndex ON Levelbank(steamid)")
	def __len__(self):
		self.execute("SELECT COUNT(*) FROM Levelbank")
		return int(self.cursor.fetchone()[0])

	def __contains__(self, user):
		if isinstance(user, (long, int)):
			self.execute("SELECT steamid FROM Levelbank WHERE UserID = ?", (user, ))
		else:
			self.execute("SELECT steamid FROM Levelbank WHERE steamid = ?", (user, ))
		return bool(self.cursor.fetchone())


	def execute(self, statement, args=None):
		if args is None:
			self.cursor.execute(statement)
		else:
			self.cursor.execute(statement, args)

	def fetchone(self):
		result = self.cursor.fetchone()
		if hasattr(result, '__iter__'):
			if len(result) == 1:
				return result[0]
		return result   

	def fetchall(self):
		trueValues = []
		for value in self.cursor.fetchall():
			if isinstance(value, tuple):
				if len(value) > 1:
					trueValues.append(value)
				else:
					trueValues.append(value[0])
			else:
				trueValues.append(value)
		return trueValues

	def save(self):
		self.connection.commit()

	def close(self):
		self.cursor.close()
		self.connection.close()
		
	def removeWarnings(self, value):
		return str(value).replace("'", "").replace('"', '')
		
	def getLevelsFromUserid(self, userid):
		self.execute("SELECT levels FROM Levelbank WHERE UserID = ?", (userid, ))
		value = self.cursor.fetchone()
		if value == 0:
			self.addLevelToUser(userid, defaultlevel)
			return defaultlevel
		return value[0]
		
	def addLevelToUser(self, userid, amount):
		self.execute("UPDATE Levelbank SET levels = ? WHERE UserID = ?", (amount, userid))
		self.execute("SELECT levels FROM Levelbank WHER UserID = ?",(userid, ))
		value = self.cursor.fetchone()
		if value[0] == 0:
			self.addLevelToUser(userid, defaultlevel)
			return defaultlevel
		return value[0]
		
	def addPlayer(self, userid, name, steamid):
		self.execute("INSERT OR IGNORE INTO Levelbank (UserID, steamid, name, levels) VALUES (?,?,?,?)",(str(userid),str(self.removeWarnings(name)),str(steamid), str(defaultlevel)))
		self.execute("SELECT UserID FROM Levelbank WHERE steamid = ?",(steamid, ))
		return self.cursor.lastrowid
		
	def getUserIdFromSteamId(self, steamid):
		self.execute("SELECT UserID FROM Levelbank WHERE steamid = ?",(steamid, ))
		v = self.cursor.fetchone()
		if v is None:
			return None
		return v[0]
	
	def takeLevels(self, userid, amount):
		self.execute("UPDATE Levelbank SET levels = ? WHERE UserID = ?", (amount, userid))
		self.execute("SELECT levels FROM Levelbank WHERE UserID = ?",(userid, ))
		return self.cursor.fetchone()[0]
	
	def getBanUser(self, userid):
		self.execute("SELECT ban, banTimeOut, banHours FROM Levelbank WHERE UserID = ?",(userid, ))
		v = database.fetchone()
		if v[0]:
			baninfo = {'ban':v[0],'banTimeOut':v[1],'banHours':v[2]}
			return baninfo
		return {'ban':0,'banTimeOut':0,'banHours':0}
		
	def banUser(self, userid, time, timeout):
		self.execute("UPDATE Levelbank SET ban = 1, banTimeOut = ?, banHours = ? WHERE UserID = ?",(timeout,time,userid))
		return {'ban':1,'banTimeOut':timeout,'banHours':time}
		
	def unbanUser(self, userid):
		self.execute("UPDATE Levelbank SET ban = 0, banTimeOut = 0, banHours = 0 WHERE UserID = ?",(userid, ))
		return {'ban':0,'banTimeOut':0,'banHours':0}
		
	
if dbType == 1:
	database = MySQLManager()
elif dbType == 2:
	database = SQLiteManager(Path(info.path).joinpath('data'))

class Admins(object):
	def __init__(self):
		self.admins = dict(info.getAdmins)
		
	def getAdminUser(self, steamid):
		if steamid in self.admins:
			return dict(self.admins[steamid])
		return None
		
	def getLenPermissions(self, steamid):
		len = 0
		for perm in self.admins[steamid]:
			if self.admins[steamid][perm]:
				len +=1
		return len
		
	def getPermd(self, steamid):
		permissions = {}
		for perm in self.admins[steamid]:
			if int(self.admins[steamid][perm]):
				permissions[perm] = self.admins[steamid][perm]
		return permissions
		
admins =  Admins()
		
tmp = {}		
def getPlayer(userid):
	userid = int(userid)
	if not userid in tmp:
		tmp[userid] = Player(userid)
	return tmp[userid]

class Player(object):
	def __init__(self, userid):
		player = wcs.wcs.getPlayer(userid)
		self.userid             = userid
		self.steamid            = player.steamid
		self.UserID             = player.UserID
		tmp 					= database.getUserIdFromSteamId(self.steamid)
		if tmp is None:
			database.addPlayer(self.UserID, es.getplayername(self.userid), self.steamid)
		self.levels				= database.getLevelsFromUserid(self.UserID)
		self.ban 				= database.getBanUser(self.UserID)
		self.admin				= admins.getAdminUser(self.steamid)
		
		
	def __del__(self):
		self.save()
		
	def __str__(self):
		return str(self.userid)
	
	def __int__(self):
		return self.userid
		
	def update(self):
		self.steamid, self.levels = self._getInfo(('steamid','levels'))
		
	def save(self):
		self._setInfo({'steamid':self.steamid,
						'levels':self.levels,
						'ban':self.ban['ban'],
						'ban':self.ban['banTimeOut'],
						'banHours':self.ban['banHours']})
		
	def _getInfo(self, what):		
		self.updateban()
		if dbType == 1:
			database.execute("SELECT "+','.join(map(str, what))+" FROM Levelbank WHERE UserID = %s", (self.UserID))
		elif dbType == 2:
			database.execute("SELECT "+','.join(map(str, what))+" FROM Levelbank WHERE UserID = ?", (self.UserID, ))
		v = database.fetchone()
		if v is None:
			return (es.getplayersteamid(self.userid), defaultlevel)
		return v
	def _setInfo(self, options):
		keys = []
		for option, value in options.iteritems():
			keys.append((option+"='"+str(value)+"'"))
		if dbType == 1:
			database.execute("UPDATE Levelbank SET " + ','.join(keys) + " WHERE UserID = %s", (self.UserID))
		elif dbType == 2:
			database.execute("UPDATE Levelbank SET " + ','.join(keys) + " WHERE UserID = ?", (self.UserID, ))
		self.ban = database.getBanUser(self.UserID)
		
	def addLevels(self, amount):
		self.levels += amount
		database.addLevelToUser(self.UserID, self.levels)
		events.Event('wcs_leveladd').set({'userid':self.userid,'amount':amount}).fire()
		return self.levels
		
	def takeLevels(self, amount):
		if self.levels < amount:
			return
		self.levels -= amount
		database.takeLevels(self.UserID, self.levels)
		events.Event('wcs_leveltake').set({'userid':self.userid,'amount':amount}).fire()
		return self.levels
	
	def banUser(self, time1):
		timeOut = time.time()+time1*3600
		database.banUser(self.UserID, time1, timeOut)
		events.Event('wcs_userban').set({'userid':self.userid,'time':time1}).fire()
		self.ban = {'ban':1,'banTimeOut':timeOut,'banHours':time1}
	
	def unban(self):
		database.unbanUser(self.UserID)
		events.Event('wcs_userunban').set({'userid':self.userid}).fire()
		self.ban = {'ban':0,'banTimeOut':0,'banHours':0}
		
	def updateban(self):	
		self.ban = database.getBanUser(self.UserID)
		
	def checkBan(self):
		if self.ban['ban']:
			time1 = time.time()
			banTimeOut = self.ban['banTimeOut']
			if time1 >= banTimeOut:
				self.ban = {'ban':0,'banTimeOut':0,'banHours':0}
				self.unban()
				return 0
			timeout = banTimeOut -time1
			min = 1
			hour = 0
			days = 0
			while timeout >= 60:
				if timeout >= 86400:
					timeout -= 86400
					days += 1
				elif timeout >= 3600:
					timeout -= 3600
					hour += 1
				elif timeout >= 60:
					timeout -= 60
					min += 1
			if min or hour or day:
				return '%s|%s|%s'%(days, hour, min)
		return 0
		
		

class EventManager(object):
	def __init__(self, file):
		self.file = str(file)+'.res' if not str(file).endswith('.res') else ''
		self.load()

	def load(self):
		es.loadevents('declare', 'addons/eventscripts/levelbank/events/'+self.file)

	def Event(self, event):
		return Event(event)
		
class Event(object):
	def __init__(self, name):
		self.name = name
		es.event('initialize', self.name)

	def set(self, options={}):
		for item, value in options.iteritems():
			if str(value).isdigit():
				es.event('setint', self.name, item, int(value))
			else:
				try:
					es.event('setfloat', self.name, item, float(value))
				except ValueError:
					if value:
						es.event('setstring', self.name, item, str(value))
					else:
						es.event('setstring', self.name, item, '0')

		return self

	def fire(self):
		es.event('fire', self.name)

	def cancel(self):
		es.event('cancel', self.name)
events = EventManager('events')

class cmdlibRegister(object):
	def __init__(self):
		self.timed = {}

	@staticmethod
	def levelbank(userid, args=None):
		#levelbankmenu.mainMenu(userid)
		mainMenu(userid)

	@staticmethod
	def lbadmin(userid, args=None):
		#lbadmin.mainMenu(userid)
		#mainMenu(userid)
		lbadmin(userid)
cmdreg = cmdlibRegister()

if data['dbType'] == 1:
	DATABASE_STORAGE_METHOD = MySQLManager
elif data['dbType'] == 2:
	DATABASE_STORAGE_METHOD = SQLiteManager
databasePath = Path(info.path).joinpath('data')
	
def load():
	if data['dbType'] == 1:
		database = DATABASE_STORAGE_METHOD()
	elif data['dbType'] == 2:
		database = DATABASE_STORAGE_METHOD(databasePath)
		
	cmdlib.registerClientCommand('levelbank',  cmdreg.levelbank,  '')
	cmdlib.registerClientCommand('lb',      cmdreg.levelbank,      '')
	cmdlib.registerClientCommand('levelbanadmin',  cmdreg.lbadmin,  '')
	cmdlib.registerClientCommand('lbadmin',     cmdreg.lbadmin,     '')
	cmdlib.registerSayCommand('levelbank',     cmdreg.levelbank,  '')
	cmdlib.registerSayCommand('lb',         cmdreg.levelbank,      '')
	cmdlib.registerSayCommand('levelbanadmin',     cmdreg.lbadmin,  '')
	cmdlib.registerSayCommand('lbadmin',     cmdreg.lbadmin,  '')
	
def unload():
	cmdlib.unregisterClientCommand('levelbank')
	cmdlib.unregisterClientCommand('lb')
	cmdlib.unregisterClientCommand('levelbanadmin')
	cmdlib.unregisterClientCommand('lbadmin')
	cmdlib.unregisterSayCommand('levelbank')
	cmdlib.unregisterSayCommand('lb')
	cmdlib.unregisterSayCommand('levelbanadmin')
	cmdlib.unregisterSayCommand('lbadmin')	
	database.save()
	database.close()
	tmp.clear()

def tell(userid, text, tokens={}, extra='', lng=True):
	if str(userid).startswith('#'):
		userid = playerlib.getPlayerList(userid)

	if not userid:
		return

	if not hasattr(userid, '__iter__'):
		if not es.exists('userid', userid):
			return

		userid = (userid, )

	for user in userid:
		if es.exists('userid', user) and not es.isbot(user):
			if lng:
				try:
					text = strings(text, tokens, langlib.getLangAbbreviation(es.getclientvar(user, 'cl_language')))
				except:
					logging.log('wcs: There was a error when trying to find the text "'+str(text)+'"')
					sys.excepthook(*sys.exc_info())
					return

			if not text:
				continue
			text = '#default[Level bank]:'+str(text)
			if len(extra):
				if '#darkgreen' in text or '#darkgreen' in extra:
					es.tell(userid, '#multi', str(text%extra).replace('#darkgreen', '\x05'))
				else:
					saytextlib.sayText2(userid, es.getindexfromhandle(es.getplayerhandle(userid)), str(text%extra))
			else:
				if '%s' in text:
					text = text.replace('%s', '')

				if '#darkgreen' in text:
					es.tell(userid, '#multi', text.replace('#darkgreen', '\x05'))
				else:
					saytextlib.sayText2(userid, es.getindexfromhandle(es.getplayerhandle(user)), text)
	
def server_shutdown(ev):
	tmp.clear()
	database.save()
	database.close()

def round_end(ev):
	for x in tmp:
		tmp[x].save()
	database.save()

def player_disconnect(ev):
	userid = int(ev['userid'])
	if userid in tmp:
		tmp[userid].save()
		del tmp[userid]
		
def player_activate(ev):
	userid = str(ev['userid'])
	if es.exists('userid', userid):
		player = getPlayer(userid)
		
		
text = langlib.Strings(info.path + "/ini/strings.ini")
popups = []

def mainMenu(userid):
	#userid  = int(userid)
	if es.exists('userid', userid):
		player = getPlayer(userid)
		ban = player.checkBan()
		plang = playerlib.getPlayer(userid).lang
		if ban:
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			tell(userid, 'ban', {'timeout':timeout})
			return
		pname = 'levelbankmain_%s'%(str(userid))
		popups.append(pname)
		mainmenu = create(pname)
		mainmenu.addline(str(text['addon name'][plang]))
		mainmenu.addline(str(text['balance'][plang])+' '+str(player.levels))
		mainmenu.addline('-'*20)
		mainmenu.menuselect = mainMenuHandler
		mainmenu.addline('->1. '+str(text['spend levels'][plang]))
		mainmenu.addline('->2. '+str(text['sent levels'][plang]))
		added = 3
		if buylevels:
			mainmenu.addline('->'+str(added)+'. '+str(text['buy levels'][plang]))
			added += 1
		if selllevels:
			mainmenu.addline('->'+str(added)+'. '+str(text['sell levels'][plang]))
		mainmenu.addline(' ')
		mainmenu.addline('-'*20)
		mainmenu.addline('0. '+str(text['exit'][plang]))
		mainmenu.send(userid)
		
def mainMenuHandler(userid, choice, popupid):
	if choice in xrange(1,5):
		if choice == 1:
			spendLevels(userid)
		elif choice == 2:
			sentLevels(userid)
		elif choice == 3:
			if buylevels:
				buyLevels(userid)
			elif selllevels:
				sellLevels(userid)
			else:
				send(popupid, userid)
		elif choice == 4:
			if selllevels:
				sellLevels(userid)
			else:
				send(popupid, userid)
def spendLevels(userid):
	userid  = int(userid)
	if es.exists('userid', userid):
		player = getPlayer(userid)
		ban = player.checkBan()
		plang = playerlib.getPlayer(userid).lang
		if ban:
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			tell(userid, 'ban', {'timeout':timeout})
			return
		pname = 'levelbankspendlevels_%s'%(str(userid))
		popups.append(pname)
		spendlevels = create(pname)
		spendlevels.addline(str(text['addon name'][plang])+': '+str(text['spend levels'][plang]))
		spendlevels.addline(str(text['balance'][plang])+' '+str(player.levels))
		spendlevels.addline('-'*20)
		spendlevels.addline(str(text['chose amount levels'][plang]))
		spendlevels.menuselect = spendLevelsHandler
		if player.levels >= 1:
			spendlevels.addline('->1. 1')
		else:
			spendlevels.addline('1. 1')
		if player.levels >= 5:
			spendlevels.addline('->2. 5')
		else:
			spendlevels.addline('2. 5')
		if player.levels >= 10:
			spendlevels.addline('->3. 10')
		else:
			spendlevels.addline('3. 10')
		if player.levels >= 20:
			spendlevels.addline('->4. 20')
		else:
			spendlevels.addline('4. 20')
		if player.levels >= 40:	
			spendlevels.addline('->5. 40')
		else:
			spendlevels.addline('->5. 40')
		spendlevels.addline('->6. '+str(text['custom'][plang]))
		spendlevels.addline('-'*20)
		spendlevels.addline('->8. '+str(text['back'][plang]))
		spendlevels.addline('0. '+str(text['exit'][plang]))
		spendlevels.send(userid)
		
def spendLevelsHandler(userid, choice, popupid):
	if choice in xrange(1, 7):
		player = getPlayer(userid)
		ban = player.checkBan()
		if ban:
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			tell(userid, 'ban', {'timeout':timeout})
			return
		playerWcs = wcs.wcs.getPlayer(userid)
		if choice == 1:
			if player.levels >= 1:
				player.takeLevels(1)
				playerWcs.giveLevel(1)
				tell(userid, 'level take', {'amount':1})
		elif choice == 2:
			if player.levels >= 5:
				player.takeLevels(5)
				playerWcs.giveLevel(5)	
				tell(userid, 'level take', {'amount':5})
		elif choice == 3:
			if player.levels >= 10:
				player.takeLevels(10)
				playerWcs.giveLevel(10)	
				tell(userid, 'level take', {'amount':10})
		elif choice == 4:
			if player.levels >= 20:
				player.takeLevels(20)
				playerWcs.giveLevel(20)	
				tell(userid, 'level take', {'amount':20})
		elif choice == 5:
			if player.levels >= 40:
				player.takeLevels(40)
				playerWcs.giveLevel(40)	
				tell(userid, 'level take', {'amount':40})
		elif choice == 6:
			wcs.wcs.wcsgroup.setUser(userid, 'levelbank_levelchat', 1)
			tell(userid, 'level to chat')
			gamethread.delayed(15, wcs.wcs.wcsgroup.setUser, (userid, 'levelbank_levelchat', 0), 0)
	elif choice == 8:
		mainMenu(userid)


def sentLevels(userid):
	if es.exists('userid', userid):
		pname = 'lb_sentlevels_'+str(userid)
		popups.append(pname)
		popup = easymenu(pname, '_popup_choice', sentLevelsHeandler)
		plang = playerlib.getPlayer(userid).lang
		popup.settitle(str(text['addon name'][plang])+': '+str(text['sent levels'][plang])+'\n '+str(text['chose player'][plang]))
		popup.settitle(str(text['page'][plang]))
		popup.c_beginsep = '-'*25
		popup.c_pagesep = '-'*25

		for user in es.getUseridList():
			popup.addoption(user, es.getplayername(user))

		popup.send(userid)

def sentLevelsHeandler(userid, target, popupid):
	if es.exists('userid', target):
		sentLevels1(userid, 'lb_sentlevels2_%s_%s'%(target,userid))
	else:
		send(popupid, userid)

def sentLevels1(userid, popupid):
	userid = int(userid)
	target = int(popupid.split('_')[2])
	if es.exists('userid', userid) and es.exists('userid', target):
		player = getPlayer(userid)
		playerTr = getPlayer(target)
		plang = playerlib.getPlayer(userid).lang
		ban = player.checkBan()
		if ban:
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			tell(userid, 'ban', {'timeout':timeout})
			return
		pname = 'lbSentLevels2_%s_%s'%(userid, target)
		popups.append(pname)
		sentlevels = create(pname)
		sentlevels.addline(str(text['addon name'][plang])+': '+str(text['sent levels'][plang]))
		sentlevels.addline(str(text['balance'][plang])+' '+str(player.levels))
		sentlevels.addline('-'*20)
		sentlevels.addline(str(text['chose amount levels'][plang]))
		sentlevels.menuselect = sentLevelsHandler2
		if player.levels >= 1:
			sentlevels.addline('->1. 1')
		else:
			sentlevels.addline('1. 1')
		if player.levels >= 5:
			sentlevels.addline('->2. 5')
		else:
			sentlevels.addline('2. 5')
		if player.levels >= 10:
			sentlevels.addline('->3. 10')
		else:
			sentlevels.addline('3. 10')
		if player.levels >= 20:
			sentlevels.addline('->4. 20')
		else:
			sentlevels.addline('4. 20')
		if player.levels >= 40:	
			sentlevels.addline('->5. 40')
		else:
			sentlevels.addline('->5. 40')
		sentlevels.addline('->6. '+str(text['custom'][plang]))
		sentlevels.addline('-'*20)
		sentlevels.addline('->8. '+str(text['back'][plang]))
		sentlevels.addline('0. '+str(text['exit'][plang]))
		sentlevels.send(userid)
		
def sentLevelsHandler2(userid, choice, popupid):
	target = int(popupid.split('_')[2])
	if choice in xrange(1, 7):
		player = getPlayer(userid)
		ban = player.checkBan()
		if ban:
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			tell(userid, 'ban', {'timeout':timeout})
			return
		playerTr = getPlayer(target)
		if choice == 1:
			if player.levels >= 1:
				player.takeLevels(1)
				playerTr.addLevels(1)
				tell(target, 'level get' ,{'name':es.getplayername(userid),'amount':1})
				tell(userid, 'level take', {'amount':1})
		elif choice == 2:
			if player.levels >= 5:
				player.takeLevels(5)
				playerTr.addLevels(5)
				tell(target, 'level get' ,{'name':es.getplayername(userid),'amount':5})
				tell(userid, 'level take', {'amount':5})
		elif choice == 3:
			if player.levels >= 10:
				player.takeLevels(10)
				playerTr.addLevels(10)
				tell(target, 'level get' ,{'name':es.getplayername(userid),'amount':10})
				tell(userid, 'level take', {'amount':10})
		elif choice == 4:
			if player.levels >= 20:
				player.takeLevels(20)
				playerTr.addLevels(20)
				tell(target, 'level get' ,{'name':es.getplayername(userid),'amount':20})
				tell(userid, 'level take', {'amount':20})
		elif choice == 5:
			if player.levels >= 40:
				player.takeLevels(40)
				playerTr.addLevels(40)
				tell(target, 'level get' ,{'name':es.getplayername(userid),'amount':40})
				tell(userid, 'level take', {'amount':40})
		elif choice == 6:
			wcs.wcs.wcsgroup.setUser(userid, 'levelbank_levelchat_sent', target)
			tell(userid, 'level to chat')
			gamethread.delayed(15, wcs.wcs.wcsgroup.setUser, (userid, 'levelbank_levelchat_sent', 0), 0)
	elif choice == 8:
		mainMenu(userid)
		
def buyLevels(userid):
	userid = int(userid)
	if es.exists('userid', userid):
		player = getPlayer(userid)
		plang = playerlib.getPlayer(userid).lang
		ban = player.checkBan()
		if ban:
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			tell(userid, 'ban', {'timeout':timeout})
			return
		pname = 'lbBuyLevels_%s'%(userid)
		popups.append(pname)
		buylevels = create(pname)
		buylevels.addline(str(text['addon name'][plang])+': '+str(text['buy levels'][plang]))
		buylevels.addline(str(text['balance'][plang])+' '+str(player.levels))
		buylevels.addline(str(text['level price'][plang])+' '+str(data['levelprice']))
		buylevels.addline('-'*20)
		buylevels.menuselect = buyLevelsHeandler
		if playerlib.getPlayer(userid).cash >= data['levelprice']:
			buylevels.addline('->1. 1'+str(text['lvl'][plang]))
		else:
			buylevels.addline('1. 1'+str(text['lvl'][plang]))
		buylevels.addline('->2. '+str(text['custom'][plang]))
		buylevels.addline(' ')
		buylevels.addline(' ')
		buylevels.addline(' ')
		buylevels.addline('-'*20)
		buylevels.addline('->8. '+str(text['back'][plang]))
		buylevels.addline('0. '+str(text['exit'][plang]))
		buylevels.send(userid)
		
def buyLevelsHeandler(userid, choice, popupid):
	if choice in xrange(1,3):
		player = getPlayer(userid)
		if choice == 1:
			if playerlib.getPlayer(userid).cash < data['levelprice']:
				tell(userid, 'not enough money')
				return
			playerlib.getPlayer(userid).cash -= data['levelprice']
			player.addLevels(1)
			tell(userid, 'level buy', {'amount':1,'price':data['levelprice']})
		elif choice == 2:
			wcs.wcs.wcsgroup.setUser(userid, 'levelbank_levelchat_buy', 1)
			tell(userid, 'level to chat')
			gamethread.delayed(15, wcs.wcs.wcsgroup.setUser, (userid, 'levelbank_levelchat_buy', 0), 0)
	elif choice == 8:
		mainMenu(userid)

def sellLevels(userid):
	userid = int(userid)
	if es.exists('userid', userid):
		player = getPlayer(userid)
		plang = playerlib.getPlayer(userid).lang
		ban = player.checkBan()
		if ban:
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			tell(userid, 'ban', {'timeout':timeout})
			return
		pname = 'lbSellLevels_%s'%(userid)
		popups.append(pname)
		selllevels = create(pname)
		selllevels.addline(str(text['addon name'][plang])+': '+str(text['sell levels'][plang]))
		selllevels.addline(str(text['balance'][plang])+' '+str(player.levels))
		selllevels.addline(str(text['level cost'][plang])+' '+str(data['levelcost']))
		selllevels.addline('-'*20)
		selllevels.menuselect = sellLevelsHeandler
		if player.levels >= 1:
			selllevels.addline('->1. 1'+str(text['lvl'][plang]))
		else:
			selllevels.addline('1. 1'+str(text['lvl'][plang]))
		if player.levels >= 5:
			selllevels.addline('->2. 5'+str(text['lvl'][plang]))
		else:
			selllevels.addline('2. 5'+str(text['lvl'][plang]))
		if player.levels >= 10:
			selllevels.addline('->3. 10'+str(text['lvl'][plang]))
		else:
			selllevels.addline('3. 10'+str(text['lvl'][plang]))
		if player.levels >= 20:
			selllevels.addline('->4. 20'+str(text['lvl'][plang]))
		else:
			selllevels.addline('4. 20'+str(text['lvl'][plang]))
		if player.levels >= 40:
			selllevels.addline('->5. 40'+str(text['lvl'][plang]))
		else:
			selllevels.addline('5. 40'+str(text['lvl'][plang]))
		selllevels.addline('->6. '+str(text['custom'][plang]))
		selllevels.addline('-'*20)
		selllevels.addline('->8. '+str(text['back'][plang]))
		selllevels.addline('0. '+str(text['exit'][plang]))
		selllevels.send(userid)
		
def sellLevelsHeandler(userid, choice, popupid):
	if choice in xrange(1, 7):
		player = getPlayer(userid)
		playerPL = playerlib.getPlayer(userid)
		ban = player.checkBan()
		if ban:
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			tell(userid, 'ban', {'timeout':timeout})
			return
		if choice == 1:
			if player.levels >= 1:
				player.takeLevels(1)
				price = 1*data['levelcost']
				playerPL.cash += price
				tell(userid, 'level sell', {'amount':1, 'price':price})
		elif choice == 2:
			if player.levels >= 5:
				player.takeLevels(5)
				price = 5*data['levelcost']
				playerPL.cash += price
				tell(userid, 'level sell', {'amount':5, 'price':price})
		elif choice == 3:
			if player.levels >= 10:
				player.takeLevels(10)
				price = 10*data['levelcost']
				playerPL.cash += price
				tell(userid, 'level sell', {'amount':10, 'price':price})
		elif choice == 4:
			if player.levels >= 20:
				player.takeLevels(20)
				price = 20*data['levelcost']
				playerPL.cash += price
				tell(userid, 'level sell', {'amount':20, 'price':price})
		elif choice == 5:
			if player.levels >= 40:
				player.takeLevels(40)
				price = 40*data['levelcost']
				playerPL.cash += price
				tell(userid, 'level sell', {'amount':40, 'price':price})
		elif choice == 6:
			wcs.wcs.wcsgroup.setUser(userid, 'levelbank_levelchat_sell', 1)
			tell(userid, 'level to chat')
			gamethread.delayed(15, wcs.wcs.wcsgroup.setUser, (userid, 'levelbank_levelchat_sell', 0), 0)
	elif choice == 8:
		mainMenu(userid)
			
def lbadmin(userid):
	if es.exists('userid', userid):
		player = getPlayer(userid)
		steamid = wcs.wcs.getPlayer(userid).steamid
		if not steamid in admins.admins.keys():
			tell(userid, 'not admin')
			return
		plang = playerlib.getPlayer(userid).lang
		pname = 'lbAdmins=%s=%s'%(userid,steamid)
		popups.append(pname)
		lbadmin = create(pname)
		lbadmin.addline(str(text['addon name'][plang])+': '+str(text['admin menu'][plang]))
		lbadmin.addline('-'*20)
		lbadmin.menuselect = lbAdminHandler
		items = admins.getPermd(steamid).keys()
		for x in xrange(1, len(items)+1):
			lbadmin.addline('->'+str(x)+'. '+str(text[items[x-1]][plang]))
		lbadmin.addline('-'*20)
		lbadmin.addline('0. '+str(text['exit'][plang]))
		lbadmin.send(userid)
		
def lbAdminHandler(userid, choice, popupid):
	steamid = popupid.split('=')[2]
	if choice in xrange(1, admins.getLenPermissions(steamid)+1):
		items = admins.getPermd(steamid).keys()
		choicecat = items[choice-1]
		if choicecat == 'addlevels':
			chousePlayer(userid, 'lb_addlevels_%s'%(userid))
		elif choicecat == 'addlevelall':
			admin_addLevelsAll(userid)
		elif choicecat == 'takelevels':
			chousePlayer(userid, 'lb_takelevels_%s'%(userid))
		elif choicecat == 'banusers':
			chousePlayer(userid, 'lb_banusers_%s'%(userid))
		elif choicecat == 'unbanusers':
			chousePlayer(userid, 'lb_unbanusers_%s'%(userid))
		elif choicecat == 'deletedatabase':
			admin_deleteDB(userid)
		
def chousePlayer(userid, args):
	steamid = wcs.wcs.getPlayer(userid).steamid
	if not steamid in admins.admins.keys():
			tell(userid, 'not admin')
			return
	type = args.split('_')[1]
	if es.exists('userid', userid):
		pname = 'lbchouseplayer_%s_%s'%(type, userid)
		popups.append(pname)
		plang = playerlib.getPlayer(userid).lang
		popup = easymenu(pname, '_popup_choice', chousePlayerHeandler)
		popup.settitle(str(text['addon name'][plang])+': '+str(text[type][plang]).lower()+'\n '+str(text['chose player'][plang]))
		popup.c_beginsep = '-'*25
		popup.c_pagesep = '-'*25

		for user in es.getUseridList():
			player = getPlayer(userid)
			if type == 'unbanusers':
				if getPlayer(user).ban['ban']:
					popup.addoption(user, es.getplayername(user))
				else:
					popup.addoption(user, es.getplayername(user), state=0)
			elif type == 'banusers':
				if not getPlayer(user).ban['ban']:
					popup.addoption(user, es.getplayername(user))
				else:
					ban = player.checkBan()
					days, hours, minets = ban.split('|')
					timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
					popup.addoption(user, es.getplayername(user)+'|'+str(text['ban time left'][plang])+' '+str(timeout), state=0)
			else:
				popup.addoption(user, es.getplayername(user))
				
					
		popup.send(userid)
		
def chousePlayerHeandler(userid, target, popupid):
	type = popupid.split('_')[1]
	if es.exists('userid', target):
		if type == 'addlevels':
			admin_addLevels(userid, target)
		elif type == 'takelevels':
			admin_takelevels(userid, target)
		elif type == 'banusers':
			admin_banuser(userid, target)
		elif type == 'unbanusers':
			admin_unbanUser(userid, target)

def admin_addLevels(userid, target):
	steamid = wcs.wcs.getPlayer(userid).steamid
	if not steamid in admins.admins.keys():
			tell(userid, 'not admin')
			return
	if es.exists('userid', userid):
		plang = playerlib.getPlayer(userid).lang
		pname = 'lbAdminAddLevels_%s_%s'%(target,userid)
		popups.append(pname)
		addlevels = create(pname)
		addlevels.addline(str(text['addon name'][plang])+': '+str(text['admin menu'][plang]))
		addlevels.addline(str(text['addlevels'][plang])+' '+str(text['to player'][plang])+' '+str(es.getplayername(target)))
		addlevels.addline('-'*20)
		addlevels.menuselect = admin_addLevelsHeandler
		addlevels.addline('->1. 1 '+str(text['lvl'][plang]))
		addlevels.addline('->2. 10 '+str(text['lvl'][plang]))
		addlevels.addline('->3. 50 '+str(text['lvl'][plang]))
		addlevels.addline('->4. 100 '+str(text['lvl'][plang]))
		addlevels.addline('->5. 500 '+str(text['lvl'][plang]))
		addlevels.addline('->6.'+str(text['custom'][plang]))
		addlevels.addline('-'*20)
		addlevels.addline('->8. '+str(text['back'][plang]))
		addlevels.addline('0.'+str(text['exit'][plang]))
		addlevels.send(userid)
		
def admin_addLevelsHeandler(userid, choice, popupid):
	target = int(popupid.split('_')[1])
	player = getPlayer(target)
	if choice in xrange(1,7):
		steamid = wcs.wcs.getPlayer(userid).steamid
		if not steamid in admins.admins.keys():
			tell(userid, 'not admin')
			return
		if choice == 1:
			player.addLevels(1)
			tell(target, 'level add',{'amount':1})
		elif choice == 2:
			player.addLevels(10)
			tell(target, 'level add',{'amount':10})
		elif choice == 3:
			player.addLevels(50)
			tell(target, 'level add',{'amount':50})
		elif choice == 4:
			player.addLevels(100)
			tell(target, 'level add',{'amount':100})
		elif choice == 5:
			player.addLevels(500)
			tell(target, 'level add',{'amount':500})
		elif choice == 6:
			wcs.wcs.wcsgroup.setUser(userid, 'lbAdminAddlevels_chat', target)
			tell(userid, 'level to chat')
			gamethread.delayed(15, wcs.wcs.wcsgroup.setUser, (userid, 'lbAdminAddlevels_chat', 0), 0)
	elif choice ==8:
		lbadmin(userid)
	
def admin_takelevels(userid, target):
	steamid = wcs.wcs.getPlayer(userid).steamid
	if not steamid in admins.admins.keys():
			tell(userid, 'not admin')
			return
	if es.exists('userid', userid):
		plang = playerlib.getPlayer(userid).lang
		pname = 'lbAdminTakeLevels_%s_%s'%(target,userid)
		player = getPlayer(target)
		popups.append(pname)
		takelevels = create(pname)
		takelevels.addline(str(text['addon name'][plang])+': '+str(text['admin menu'][plang]))
		takelevels.addline(str(text['takelevels'][plang])+' '+str(text['from player'][plang])+' '+str(es.getplayername(target)))
		takelevels.addline('-'*20)
		takelevels.menuselect = admin_takeLevelsHeandler
		if player.levels >=  1:
			takelevels.addline('->1. 1 '+str(text['lvl'][plang]))
		else:
			takelevels.addline('1. 1 '+str(text['lvl'][plang]))
		if player.levels >=  10:
			takelevels.addline('->2. 10 '+str(text['lvl'][plang]))
		else:
			takelevels.addline('2. 10 '+str(text['lvl'][plang]))
		if player.levels >=  50:
			takelevels.addline('->3. 50 '+str(text['lvl'][plang]))
		else:
			takelevels.addline('3. 50 '+str(text['lvl'][plang]))
		if player.levels >=  100:
			takelevels.addline('->4. 100 '+str(text['lvl'][plang]))
		else:
			takelevels.addline('4. 100 '+str(text['lvl'][plang]))
		if player.levels:
			takelevels.addline('->5. '+str(text['all levels'][plang]))
			takelevels.addline('->6. '+str(text['custom'][plang]))
		else:
			takelevels.addline('5. '+str(text['all levels'][plang]))
			takelevels.addline('6. '+str(text['custom'][plang]))
		takelevels.addline('-'*20)
		takelevels.addline('->8. '+str(text['back'][plang]))
		takelevels.addline('0.'+str(text['exit'][plang]))
		takelevels.send(userid)
		
		
def admin_takeLevelsHeandler(userid, choice, popupid):
	target = int(popupid.split('_')[1])
	player = getPlayer(target)
	if choice in xrange(1,7):
		steamid = wcs.wcs.getPlayer(userid).steamid
		if not steamid in admins.admins.keys():
			tell(userid, 'not admin')
			return
		if choice == 1:
			if not player.levels >= 1:
				return
			player.takeLevels(1)
			tell(target, 'level take',{'amount':1})
		elif choice == 2:
			if not player.levels >= 10:
				return
			player.takeLevels(10)
			tell(target, 'level take',{'amount':10})
		elif choice == 3:
			if not player.levels >= 50:
				return
			player.takeLevels(50)
			tell(target, 'level take',{'amount':50})
		elif choice == 4:
			if not player.levels >= 100:
				return
			player.takeLevels(100)
			tell(target, 'level take',{'amount':100})
		elif choice == 5:
			if not player.levels:
				return
			oldlvl = player.levels
			player.takeLevels(player.levels)
			tell(target, 'level take',{'amount':oldlvl})
		elif choice == 6:
			wcs.wcs.wcsgroup.setUser(userid, 'lbAdminTakelevels_chat', target)
			tell(userid, 'level to chat')
			gamethread.delayed(15, wcs.wcs.wcsgroup.setUser, (userid, 'lbAdminTakelevels_chat', 0), 0)
	elif choice == 8:
		lbadmin(userid)

def admin_banuser(userid, target):
	if es.exists('userid', userid):
		plang = playerlib.getPlayer(userid).lang
		pname = 'lbAdminBanUser_%s_%s'%(target,userid)
		player = getPlayer(target)
		popups.append(pname)
		banuser = create(pname)
		banuser.addline(str(text['addon name'][plang])+': '+str(text['admin menu'][plang]))
		banuser.addline('-'*20)
		banuser.menuselect = banUserHandler
		if player.ban['ban']:
			ban = player.checkBan()
			days, hours, minets = ban.split('|')
			timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
			banuser.addline(str(text['player'][plang])+' '+str(es.getplayername(target))+' '+str(text['already banned'][plang]))
			banuser.addline(str(text['ban time'][plang])+' '+str(player.ban['banHours'])+str(text['hours'][plang]))
			banuser.addline(str(text['ban time left'][plang])+' '+str(timeout))
		else:
			banuser.addline(str(text['chouse ban'][plang]))
			banuser.addline('->1. 1 '+str(text['hours'][plang]))
			banuser.addline('->2. 2 '+str(text['hours'][plang]))
			banuser.addline('->3. 4 '+str(text['hours'][plang]))
			banuser.addline('->4. 12 '+str(text['hours'][plang]))
			banuser.addline('->5. 1 '+str(text['days'][plang]))
			banuser.addline('->6. 7 '+str(text['days'][plang]))
			banuser.addline('->7. 30 '+str(text['days'][plang]))
		banuser.addline('-'*20)
		banuser.addline('->8. '+str(text['back'][plang]))
		banuser.send(userid)
		
def banUserHandler(userid, choice, popupid):
	target = int(popupid.split('_')[1])
	player = getPlayer(target)
	if choice in xrange(1, 8) and not player.ban['ban']:
		if choice == 1:
			player.banUser(1)
			tell(userid, 'player ban', {'time':1})
		elif choice == 2:
			player.banUser(2)
			tell(userid, 'player ban', {'time':2})
		elif choice == 3:
			player.banUser(4)
			tell(userid, 'player ban', {'time':4})
		elif choice == 4:
			player.banUser(12)
			tell(userid, 'player ban', {'time':12})
		elif choice == 5:
			player.banUser(24)
			tell(userid, 'player ban', {'time':24})
		elif choice == 6:
			player.banUser(168)
			tell(userid, 'player ban', {'time':168})
		elif choice == 7:
			player.banUser(720)
			tell(userid, 'player ban', {'time':720})
			
	elif choice == 8:
		lbadmin(userid)

		
def admin_addLevelsAll(userid):
	if es.exists('userid', userid):
		plang = playerlib.getPlayer(userid).lang
		pname = 'lbAddLevelsAll_%s'
		popups.append(pname)
		addlall = create(pname)
		addlall.addline(str(text['addon name'][plang])+': '+str(text['addlevelall'][plang]))
		addlall.addline(str(text['chose amount levels'][plang]))
		addlall.addline('-'*25)
		addlall.menuselect = admin_addAllHandler
		addlall.addline('->1. 1'+str(text['lvl'][plang]))
		addlall.addline('->2. 5'+str(text['lvl'][plang]))
		addlall.addline('->3. 10'+str(text['lvl'][plang]))
		addlall.addline('->4. 50'+str(text['lvl'][plang]))
		addlall.addline('->5. 100'+str(text['lvl'][plang]))
		addlall.addline('->6. '+str(text['custom'][plang]))
		addlall.addline('-'*25)
		addlall.addline('->8. '+str(text['back'][plang]))
		addlall.addline('0. '+str(text['exit'][plang]))
		addlall.send(userid)
		
		
def admin_addAllHandler(userid, choice, popupid):
	amount = 0
	if choice in xrange(1,7):
		if choice == 1:
			amount = 1
		elif choice == 2:
			amount = 5
		elif choice == 3:
			amount = 10
		elif choice == 4:
			amount = 50
		elif choice == 5:
			amount = 100
		elif choice == 6:
			wcs.wcs.wcsgroup.setUser(userid, 'lbAdminAddlevelsAll_chat', 1)
			tell(userid, 'level to chat')
			gamethread.delayed(15, wcs.wcs.wcsgroup.setUser, (userid, 'lbAdminAddlevelsAll_chat', 0), 0)
		if amount:
			for user in playerlib.getUseridList('#all'):
				getPlayer(user).addLevels(amount)
				tell(user, 'level add',{'amount':amount})
	elif choice == 8:
		lbadmin(userid)
	

def admin_deleteDB(userid):
	if es.exists('userid', userid):
		plang = playerlib.getPlayer(userid).lang
		pname = 'lbAdminDeleteDB_%s'
		popups.append(pname)
		dropdb = create(pname)
		dropdb.addline(str(text['addon name'][plang])+': '+str(text['deletedatabase'][plang]))
		dropdb.addline('-'*20)
		dropdb.addline(str(text['you sure db'][plang]))
		dropdb.menuselect = admin_dropDBHandler
		dropdb.addline('->5. '+str(text['no'][plang]))
		dropdb.addline('->7. '+str(text['yes'][plang]))
		dropdb.addline('-'*20)
		dropdb.addline('->8. '+str(text['back'][plang]))
		dropdb.addline('0. '+str(text['exit'][plang]))
		dropdb.send(userid)

def admin_dropDBHandler(userid, choice, popupid):
	if choice == 5 or choice == 8:
		lbadmin(userid)
	elif choice == 7:
		database.execute("DROP TABLE Levelbank")
		tell(userid, 'drop table')
		es.reload('levelbank')
		
def admin_unbanUser(userid, target):
	if es.exists('userid', userid):
		plang = playerlib.getPlayer(userid).lang
		pname = 'lbAdminUnbanUser_%s_%s'%(target, userid)
		popups.append(pname)
		unban = create(pname)
		unban.addline(str(text['addon name'][plang])+': '+str(text['unbanusers'][plang]))
		player = getPlayer(target)
		ban = player.checkBan()
		days, hours, minets = ban.split('|')
		timeout = (str(days)+str(text['days'][plang]) if int(days) else '')+(str(hours)+str(text['hours'][plang]) if int(hours) else '')+(str(minets)+str(text['min'][plang]) if int(minets) else '')
		unban.addline(str(es.getplayername(target))+' '+str(text['ban time'][plang])+str(timeout))
		unban.addline('-'*20)
		unban.addline(str(text['sure unban'][plang]))
		unban.menuselect = admin_unbanHandler
		unban.addline('->3. '+str(text['yes'][plang]))
		unban.addline('->4. '+str(text['no'][plang]))
		unban.addline('-'*20)
		unban.addline('->8. '+str(text['back'][plang]))
		unban.addline('0.'+str(text['exit'][plang]))
		unban.send(userid)
	
def admin_unbanHandler(userid, choice, popupid):
	target = int(popupid.split('_')[1])
	player = getPlayer(target)
	if choice == 3:
		if player.ban['ban']:
			player.unban()
			tell(target, 'unbanned')
	elif choice == 4 or choice == 8:
		lbadmin(userid)
		
		
		
def player_say(ev):
	userid = int(ev['userid'])
	if wcs.wcs.wcsgroup.getUser(userid, 'levelbank_levelchat'):
		if ev['text'].isdigit():
			player = getPlayer(userid)
			playerWcs = wcs.wcs.getPlayer(userid)
			if player.levels >= int(ev['text']):
				player.takeLevels(int(ev['text']))
				playerWcs.giveLevel(int(ev['text']))
				tell(userid, 'level take', {'amount':str(ev['text'])})
				wcs.wcs.wcsgroup.setUser(userid, 'levelbank_levelchat', 0)
	elif wcs.wcs.wcsgroup.getUser(userid, 'levelbank_levelchat_sent'):
		if ev['text'].isdigit():
			player = getPlayer(userid)
			playerTr = getPlayer(wcs.wcs.wcsgroup.getUser(userid, 'levelbank_levelchat_sent'))
			if player.levels >= int(ev['text']):
				target = wcs.wcs.wcsgroup.getUser(userid, 'levelbank_levelchat_sent')
				player.takeLevels(int(ev['text']))
				playerTr.addLevels(int(ev['text']))
				tell(target, 'level get' ,{'name':es.getplayername(userid),'amount':int(ev['text'])})
				tell(userid, 'level take', {'amount':str(ev['text'])})
				wcs.wcs.wcsgroup.setUser(userid, 'levelbank_levelchat_sent', 0)
	elif wcs.wcs.wcsgroup.getUser(userid, 'levelbank_levelchat_buy'):
		if ev['text'].isdigit():
			player = getPlayer(userid)
			price = int(ev['text'])*data['levelprice']
			if playerlib.getPlayer(userid).cash >= price:
				playerlib.getPlayer(userid).cash -= price
				player.addLevels(int(ev['text']))
				tell(userid, 'level buy', {'amount':str(ev['text']),'price':price})
				wcs.wcs.wcsgroup.setUser(userid, 'levelbank_levelchat_buy', 0)
	elif wcs.wcs.wcsgroup.getUser(userid, 'levelbank_levelchat_sell'):
		if ev['text'].isdigit():
			player = getPlayer(userid)
			price = int(ev['text'])*data['levelcost']
			if player.levels >= int(ev['text']):
				playerlib.getPlayer(userid).cash += price
				player.takeLevels(int(ev['text']))
				tell(userid, 'level sell', {'amount':str(ev['text']), 'price':price})
				wcs.wcs.wcsgroup.setUser(userid, 'levelbank_levelchat_sell', 0)
	elif wcs.wcs.wcsgroup.getUser(userid, 'lbAdminAddlevels_chat'):
		if ev['text'].isdigit():
			player = getPlayer(wcs.wcs.wcsgroup.getUser(userid, 'lbAdminAddlevels_chat'))
			steamid = wcs.wcs.getPlayer(userid).steamid
			target = wcs.wcs.wcsgroup.getUser(userid, 'lbAdminAddlevels_chat')
			if steamid in admins.admins.keys():
				player.addLevels(int(ev['text']))
				wcs.wcs.wcsgroup.setUser(userid, 'lbAdminAddlevels_chat', 0)
				tell(target, 'level add',{'amount':int(ev['text'])})
			else:
				tell(userid, 'not admin')
	elif wcs.wcs.wcsgroup.getUser(userid, 'lbAdminTakelevels_chat'):
		if ev['text'].isdigit():
			player = getPlayer(wcs.wcs.wcsgroup.getUser(userid, 'lbAdminTakelevels_chat'))
			steamid = wcs.wcs.getPlayer(userid).steamid
			target = wcs.wcs.wcsgroup.getUser(userid, 'lbAdminTakelevels_chat')
			if steamid in admins.admins.keys():
				if player.levels >= int(ev['text']):
					player.takeLevels(int(ev['text']))
					wcs.wcs.wcsgroup.setUser(userid, 'lbAdminTakelevels_chat', 0)
					tell(target, 'level take',{'amount':int(ev['text'])})
			else:
				tell(userid, 'not admin')
	elif wcs.wcs.wcsgroup.getUser(userid, 'lbAdminAddlevelsAll_chat'):
		if ev['text'].isdigit():
			steamid = wcs.wcs.getPlayer(userid).steamid
			if steamid in admins.admins.keys():
				for user in playerlib.getUseridList('#all'):
					getPlayer(userid).addLevels(int(ev['text']))
					tell(user, 'level add',{'amount':int(ev['text'])})
				wcs.wcs.wcsgroup.setUser(userid, 'lbAdminAddlevelsAll_chat', 0)
			else:
				tell(userid, 'not admin')
